module OnePagePerInstance
	def OnePagePerInstance::go
		model = Sketchup.active_model
		ents = model.active_entities
		sel = model.selection
		sel.clear
		active_page = model.pages.selected_page if model.pages.selected_page #Current page
		if OnePagePerInstance.ok?
			l = []
			l_pages = []
			if OnePagePerInstance.existing_dimensions?
				result = UI.messagebox("Some dimension entities found.\nDo you want to continue?", MB_YESNO, "One page per instance")
				ok = 1 if result == 6
				ok = 0 if result == 7
			else
				ok = 1
			end
			if ok == 1
				model.start_operation "One page per instance"
				tr = model.options["PageOptions"]["ShowTransition"]
				model.options["PageOptions"]["ShowTransition"] = false
				model.definitions.each{|d|l.push d if d.instances.length>0}
				
				#Instance pages
				for d in l
					inst = d.instances[0]
					n = OnePagePerInstance.get_name(d)
					new_page = model.pages.add n #Create a new page
					l_pages.push new_page #Add page to the list
					model.pages.selected_page = new_page #Current page
					ents.each{|e|e.hidden = true}
					inst.hidden = false
					model.active_view.zoom_extents #Zoom on instance
					new_page.update #Update the current page
				end
				
				#Dimension pages
				if UI.messagebox("Do you want to add dimension pages?", MB_YESNO, "One page per instance")==6
					l_p = []
					l_pages.each{|lp|l_p.push lp}
					for p in l_p
						new_name = p.name + " [Sizes]"
						model.layers.add new_name
						model.pages.selected_page = p
						new_page = model.pages.add new_name
						l_pages.push new_page
						p.update
					end
					
				end
				# OnePagePerInstance.layer_pages(l_pages)
				model.pages.each do |pa|
					puts "For Page '" + pa.name + "', active layer is '" + model.active_layer.name + "'."
				end
				model.pages.selected_page = active_page if active_page #Current page
				model.options["PageOptions"]["ShowTransition"] = tr
				model.commit_operation
			end #if ok = 1
		end #if OnePagePerInstance.ok?
	end #def OnePagePerInstance::go
	
	def OnePagePerInstance::get_name(definition)
		if definition.instances[0].typename == "Group"
			if definition.instances[0].name == ""
				return definition.name
			else
				return definition.instances[0].name
			end
		elsif definition.instances[0].typename == "ComponentInstance"
			return definition.name
		end
	end #def OnePagePerInstance::get_name(definition)
	
	def OnePagePerInstance::existing_dimensions?
		Sketchup.active_model.active_entities.each{|e|return true if e.typename.include? "Dimension"}
		return false
	end #def OnePagePerInstance::dimensions?
	
	def OnePagePerInstance::ok?
		Sketchup.active_model.active_entities.each{|e|return true if e.typename == "ComponentInstance" or e.typename == "Group"}
		return false
	end #def OnePagePerInstance::ok?
end #module OnePagePerInstance

if not file_loaded?("OnePagePerInstance.rb")
	UI.menu.add_item("One Page Per Instance"){OnePagePerInstance.go}
end
file_loaded("OnePagePerInstance.rb")